==> xfxbase-2.6.21.tar.gz: lib/XfxMenu.dart <==
part of xfxbase;

// import 'package:flutter/foundation.dart';
// import 'package:flutter/material.dart';

// import '../XStylesBase.dart';
// import '../xWidgetsBase.dart';

class XfxMenu extends StatelessWidget {
  final String? label;
  final GestureTapCallback? logOut_OnTap;
  final GestureTapCallback? nameApp_OnTap;
  final Widget? nameApp;
  final String? title;
  XAppBase? xApp;
  final EdgeInsetsGeometry? padding;
  final AlignmentGeometry? alignment;
  final bool? logOut_Visible;
  final Color? menu_BackGroundColor;
  final Color? logOut_BackGroundColor;
  final Widget? logOut_Text;
  final Widget? logOut_Icon;
  final Widget? bottomArea_Widget;
  final TextStyle? title_Style;
  final List<XMenuGroup> menuGroups;
  final double? width_menuItems;
  final double? height_menuItems;
  bool pinned_Value;
  late Function() tabLink;
  late Function() fontChange;
  final void Function()? onPressed_PinnedBTN;
  bool firstSessionIsView = false;

  ///Verrà chiamata ogni volta che lo user Tappa l'item del Menu e deve tornare il Widget da mettere nel relativo XTab csomai fosse da aprire
  late void Function(XMenuItem)? onPressed_MenuItem;
  static double menuItem_WidthDefault = 250;
  Function()? functOnSync;
  bool syncWithServer;
  //CLASS NEW
  XfxMenu(
    this.menuGroups,
    this.tabLink,
    this.fontChange, {
    this.nameApp,
    this.xApp,
    this.bottomArea_Widget,
    this.pinned_Value = true,
    this.onPressed_PinnedBTN,
    this.nameApp_OnTap,
    this.firstSessionIsView = false,
    this.height_menuItems,
    this.width_menuItems,
    this.logOut_BackGroundColor,
    this.logOut_Text,
    this.logOut_Icon,
    this.logOut_Visible,
    this.alignment,
    this.menu_BackGroundColor,
    this.label,
    this.title_Style,
    this.title,
    this.padding,
    this.logOut_OnTap,
    this.onPressed_MenuItem,
    this.functOnSync,
    this.syncWithServer = false,
  });
  Widget xBuilder_XMenu(XMenuGroup xclMenu, XAppBase xApp, BuildContext context, {String? title}) {
    return Column(children: [
      title != null && syncWithServer.not() //
          ? Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                xclMenu.image_Icon_BTN != null ? Container(height: 40, width: 40, child: Image.memory(xclMenu.image_Icon_BTN!, height: 40, width: 40)) : Container(),
                SizedBox(width: 10),
                XContainerWithLabel(title, color: xclMenu.color_BTN, textStyle: XStyles.xStyleText(fontSize: 20 / xApp.KforScale, colorText: xclMenu.label_Color ?? XColors.foregroundLight)),
              ],
            )
          : Container(),
      Stack(
        alignment: Alignment.center,
        children: [
          Column(children: [
            Wrap(
              spacing: 5,
              runSpacing: 5,
              runAlignment: WrapAlignment.center,
              alignment: WrapAlignment.center,
              children: xclMenu.items.map((xclMenuItem) {
                return XBtnbase(
                  //margin: EdgeInsets.symmetric(vertical: 5),
                  label: xclMenuItem.label,
                  label_Color: xclMenuItem.label_Color,
                  backGroundColor: xclMenuItem.color_BTN,
                  icon: xclMenuItem.icon_BTN,
                  icon_Widget: xclMenuItem.image_Icon_BTN != null ? Image.memory(xclMenuItem.image_Icon_BTN!, width: 40, height: 40) : null,
                  label_Style: XStyles.xStyTextForLargeTitle(xclMenuItem.label_Color),
                  width: width_menuItems ?? menuItem_WidthDefault,
                  height: height_menuItems,
                  onPressed: () {
                    //xclMenuItem.onPressed
                    if (xclMenuItem.onPressed != null) {
                      xclMenuItem.onPressed!(xclMenuItem);
                    }
                    //onPressed_MenuItem
                    else if (onPressed_MenuItem != null) {
                      onPressed_MenuItem!(xclMenuItem);
                    }
                    tabLink();
                  },
                );
              }).toList(),
            ),
          ])
        ],
      ),
    ]);
  }

  bool snackBar_Visible = false;

  @override
  Widget build(BuildContext context) {
    return Drawer(
        width: MediaQuery.of(context).size.width < XUtils.widthMin_Layout ? (MediaQuery.of(context).size.width - 10) : 350,
        child: Container(
            margin: EdgeInsets.only(right: 10),
            padding: EdgeInsets.only(top: 20),
            color: menu_BackGroundColor ?? Colors.white,
            child: Stack(
              alignment: Alignment.bottomCenter,
              children: [
                Column(children: [
                  SizedBox(height: 20),
                  InkWell(
                    // onTap: () {
                    //   onPressed_PinnedBTN != null ? onPressed_PinnedBTN!() : null;
                    // },
                    child: Container(
                        margin: EdgeInsets.only(bottom: 10),
                        child: Row(children: [
                          (logOut_Visible ?? false) && syncWithServer.not()
                              ? XBtnbase(
                                  margin: EdgeInsets.symmetric(horizontal: 8),
                                  icon: Icons.power_settings_new,
                                  width: 50,
                                  height: 50,
                                  onPressed: logOut_OnTap,
                                  icon_Color: Colors.red,
                                )
                              : Container(),
                          title != ""
                              ? Flexible(
                                  child: Container(
                                      color: Colors.transparent,
                                      alignment: Alignment.centerLeft,
                                      margin: EdgeInsets.only(left: 10),
                                      child: Text(
                                        title ?? "",
                                        style: title_Style ?? XStyles.xStyleText(fontSize: 16, colorText: XColors.backgroundDark, letterSpacing: 1.5),
                                      )))
                              : Flexible(child: Container()),
                          xApp!.app_Version != ""
                              ? Container(
                                  color: Colors.transparent,
                                  alignment: Alignment.centerLeft,
                                  margin: EdgeInsets.only(left: 10),
                                  child: Text(
                                    " (v.${xApp!.app_Version})",
                                    style: XStyles.xStyleText(fontSize: 14, colorText: XColors.foregroundLight, letterSpacing: 1),
                                  ))
                              : Container(),
                          firstSessionIsView
                              ? XBtnbase(
                                  icon: MediaQuery.of(context).size.width < XUtils.widthMin_Layout ? Icons.close : (pinned_Value ? Icons.arrow_back_ios : Icons.arrow_forward_ios_rounded),
                                  icon_Color: XColors.backgroundLight,
                                  width: 40,
                                  height: 40,
                                  onPressed: () {
                                    onPressed_PinnedBTN != null ? onPressed_PinnedBTN!() : null;
                                  })
                              : Container()
                        ])),
                  ),
                  Expanded(
                      child: SingleChildScrollView(
                    child: syncWithServer.not()
                        ? Column(
                            children: [
                              Wrap(spacing: 5, runSpacing: 5, alignment: WrapAlignment.start, children: menuGroups.map((xclMenu) => xBuilder_XMenu(xclMenu, xApp!, context, title: menuGroups.first.label == xclMenu.label ? null : xclMenu.label)).toList()),
                              SizedBox(height: 20),
                              Row(children: [Expanded(child: Text("Sistema", textAlign: TextAlign.center, style: XStyles.xStyleText(fontSize: 20 / xApp!.KforScale, colorText: XColors.foregroundLight)))]),
                              SizedBox(height: 5),
                              Row(
                                children: [
                                  Expanded(
                                      child: XBtnbase(
                                    margin: EdgeInsets.symmetric(vertical: 5, horizontal: 40),
                                    label: "Sincronizza",
                                    icon_WidthArea: 30,
                                    label_Color: Colors.red,
                                    backGroundColor: Color.fromARGB(255, 58, 58, 58),
                                    icon: Icons.refresh,
                                    label_Style: XStyles.xStyTextForLargeTitle(Colors.red),
                                    width: width_menuItems ?? menuItem_WidthDefault,
                                    height: height_menuItems,
                                    onPressed: functOnSync != null
                                        ? () async {
                                            functOnSync!();
                                            snackBar_Visible = true;
                                            await Timer(Duration(seconds: 1), () {
                                              snackBar_Visible = false;
                                            });
                                          }
                                        : null,
                                  ))
                                ],
                              ),
                              Row(children: [
                                Expanded(
                                    child: Container(
                                        child: XBtnbase(
                                  margin: EdgeInsets.symmetric(vertical: 5, horizontal: 40),
                                  label: "Font Editor",
                                  icon_WidthArea: 30,
                                  label_Color: Colors.purple,
                                  backGroundColor: Color.fromARGB(255, 58, 58, 58),
                                  icon: Icons.settings,
                                  label_Style: XStyles.xStyTextForLargeTitle(Colors.purple),
                                  width: width_menuItems ?? menuItem_WidthDefault,
                                  height: height_menuItems,
                                  onPressed: fontChange,
                                ))),
                              ]),
                              Row(children: [Expanded(child: bottomArea_Widget ?? Container())])
                            ],
                          )
                        : Container(color: Colors.transparent, width: width_menuItems, height: MediaQuery.of(context).size.height / 1.5, child: XStatefulWidgetBase.LoaderIndicator(syncWithServer, label: "...caricamento dei dati...")),
                  )),
                  SizedBox(height: 15)
                ]),
                snackBar_Visible
                    ? XContainerWithLabel(
                        'Aggiornati con successo i dati dal server',
                        color: Colors.black,
                        textStyle: XStyles.xStyTextForSubDescr(Colors.amber),
                      )
                    : Container()
              ],
            )));
  }
}

class XMenuGroup {
  String key;
  int? idx;
  String? label;
  List<XMenuItem> items = List<XMenuItem>.empty(growable: true);
  Color? label_Color;
  Color? color_BTN;
  IconData? icon_BTN;
  Uint8List? image_Icon_BTN;
  bool expanded = true;
  XMenuGroup(
    this.key, {
    this.label,
    this.idx,
    this.label_Color,
    this.color_BTN,
    this.icon_BTN,
    this.image_Icon_BTN,
    expanded,
    required this.items,
  });
  addMenuItem(XMenuItem item) {
    this.items.add(item);
  }
}

class XMenuItem {
  String key;
  int? idx;
  String? label;
  Color? label_Color;
  Color? color_BTN;
  IconData? icon_BTN;
  Uint8List? image_Icon_BTN;
  XMenuGroup? parent;

  Function(XMenuItem)? onPressed;

  ///uso futuro
  bool active = true;

  XMenuItem(
    this.key, {
    this.label,
    this.idx,
    this.label_Color,
    this.color_BTN,
    this.onPressed,
    this.icon_BTN,
    this.image_Icon_BTN,
    this.parent,
  });
}

==> xfxbase-2.6.22.tar.gz: lib/XfxMenu.dart <==
part of xfxbase;

// import 'package:flutter/foundation.dart';
// import 'package:flutter/material.dart';

// import '../XStylesBase.dart';
// import '../xWidgetsBase.dart';

class XfxMenu extends StatelessWidget {
  final String? label;
  final GestureTapCallback? logOut_OnTap;
  final GestureTapCallback? nameApp_OnTap;
  final Widget? nameApp;
  final String? title;
  XAppBase? xApp;
  final EdgeInsetsGeometry? padding;
  final AlignmentGeometry? alignment;
  final bool? logOut_Visible;
  final Color? menu_BackGroundColor;
  final Color? logOut_BackGroundColor;
  final Widget? logOut_Text;
  final Widget? logOut_Icon;
  final Widget? bottomArea_Widget;
  final TextStyle? title_Style;
  final List<XMenuGroup> menuGroups;
  final double? width_menuItems;
  final double? height_menuItems;
  bool pinned_Value;
  late Function() tabLink;
  late Function() fontChange;
  final void Function()? onPressed_PinnedBTN;
  bool firstSessionIsView = false;

  ///Verrà chiamata ogni volta che lo user Tappa l'item del Menu e deve tornare il Widget da mettere nel relativo XTab csomai fosse da aprire
  late void Function(XMenuItem)? onPressed_MenuItem;
  static double menuItem_WidthDefault = 250;
  Function()? functOnSync;
  bool syncWithServer;
  //CLASS NEW
  XfxMenu(
    this.menuGroups,
    this.tabLink,
    this.fontChange, {
    this.nameApp,
    this.xApp,
    this.bottomArea_Widget,
    this.pinned_Value = true,
    this.onPressed_PinnedBTN,
    this.nameApp_OnTap,
    this.firstSessionIsView = false,
    this.height_menuItems,
    this.width_menuItems,
    this.logOut_BackGroundColor,
    this.logOut_Text,
    this.logOut_Icon,
    this.logOut_Visible,
    this.alignment,
    this.menu_BackGroundColor,
    this.label,
    this.title_Style,
    this.title,
    this.padding,
    this.logOut_OnTap,
    this.onPressed_MenuItem,
    this.functOnSync,
    this.syncWithServer = false,
  });
  Widget xBuilder_XMenu(XMenuGroup xclMenu, XAppBase xApp, BuildContext context, {String? title}) {
    return Column(children: [
      title != null && syncWithServer.not() //
          ? Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                xclMenu.image_Icon_BTN != null ? Container(height: 40, width: 40, child: Image.memory(xclMenu.image_Icon_BTN!, height: 40, width: 40)) : Container(),
                SizedBox(width: 10),
                XContainerWithLabel(title, color: xclMenu.color_BTN, textStyle: XStyles.xStyleText(fontSize: 20 / xApp.KforScale, colorText: xclMenu.label_Color ?? XColors.foregroundLight)),
              ],
            )
          : Container(),
      Stack(
        alignment: Alignment.center,
        children: [
          Column(children: [
            Wrap(
              spacing: 5,
              runSpacing: 5,
              runAlignment: WrapAlignment.center,
              alignment: WrapAlignment.center,
              children: xclMenu.items.map((xclMenuItem) {
                return XBtnbase(
                  //margin: EdgeInsets.symmetric(vertical: 5),
                  label: xclMenuItem.label,
                  label_Color: xclMenuItem.label_Color,
                  backGroundColor: xclMenuItem.color_BTN,
                  icon: xclMenuItem.icon_BTN,
                  icon_Widget: xclMenuItem.image_Icon_BTN != null ? Image.memory(xclMenuItem.image_Icon_BTN!, width: 40, height: 40) : null,
                  label_Style: XStyles.xStyTextForLargeTitle(xclMenuItem.label_Color),
                  width: width_menuItems ?? menuItem_WidthDefault,
                  height: height_menuItems,
                  onPressed: () {
                    //xclMenuItem.onPressed
                    if (xclMenuItem.onPressed != null) {
                      xclMenuItem.onPressed!(xclMenuItem);
                    }
                    //onPressed_MenuItem
                    else if (onPressed_MenuItem != null) {
                      onPressed_MenuItem!(xclMenuItem);
                    }
                    tabLink();
                  },
                );
              }).toList(),
            ),
          ])
        ],
      ),
    ]);
  }

  bool snackBar_Visible = false;

  @override
  Widget build(BuildContext context) {
    return Drawer(
        width: MediaQuery.of(context).size.width < XUtils.widthMin_Layout ? (MediaQuery.of(context).size.width - 10) : 350,
        child: Container(
            margin: EdgeInsets.only(right: 10),
            padding: EdgeInsets.only(top: 20),
            color: menu_BackGroundColor ?? Colors.white,
            child: Stack(
              alignment: Alignment.bottomCenter,
              children: [
                Column(children: [
                  SizedBox(height: 20),
                  InkWell(
                    // onTap: () {
                    //   onPressed_PinnedBTN != null ? onPressed_PinnedBTN!() : null;
                    // },
                    child: Container(
                        margin: EdgeInsets.only(bottom: 10),
                        child: Row(children: [
                          (logOut_Visible ?? false) && syncWithServer.not()
                              ? XBtnbase(
                                  margin: EdgeInsets.symmetric(horizontal: 8),
                                  icon: Icons.power_settings_new,
                                  width: 50,
                                  height: 50,
                                  onPressed: logOut_OnTap,
                                  icon_Color: Colors.red,
                                )
                              : Container(),
                          title != ""
                              ? Flexible(
                                  child: Container(
                                      color: Colors.transparent,
                                      alignment: Alignment.centerLeft,
                                      margin: EdgeInsets.only(left: 10),
                                      child: Text(
                                        title ?? "",
                                        style: title_Style ?? XStyles.xStyleText(fontSize: 16, colorText: XColors.backgroundDark, letterSpacing: 1.5),
                                      )))
                              : Flexible(child: Container()),
                          xApp!.app_Version != ""
                              ? Container(
                                  color: Colors.transparent,
                                  alignment: Alignment.centerLeft,
                                  margin: EdgeInsets.only(left: 10),
                                  child: Text(
                                    " (v.${xApp!.app_Version})",
                                    style: XStyles.xStyleText(fontSize: 14, colorText: XColors.foregroundLight, letterSpacing: 1),
                                  ))
                              : Container(),
                          firstSessionIsView
                              ? XBtnbase(
                                  icon: MediaQuery.of(context).size.width < XUtils.widthMin_Layout ? Icons.close : (pinned_Value ? Icons.arrow_back_ios : Icons.arrow_forward_ios_rounded),
                                  icon_Color: XColors.backgroundLight,
                                  width: 40,
                                  height: 40,
                                  onPressed: () {
                                    onPressed_PinnedBTN != null ? onPressed_PinnedBTN!() : null;
                                  })
                              : Container()
                        ])),
                  ),
                  Expanded(
                      child: SingleChildScrollView(
                    child: syncWithServer.not()
                        ? Column(
                            children: [
                              Wrap(spacing: 5, runSpacing: 5, alignment: WrapAlignment.start, children: menuGroups.map((xclMenu) => xBuilder_XMenu(xclMenu, xApp!, context, title: menuGroups.first.label == xclMenu.label ? null : xclMenu.label)).toList()),
                              SizedBox(height: 20),
                              Row(children: [Expanded(child: Text("Sistema", textAlign: TextAlign.center, style: XStyles.xStyleText(fontSize: 20 / xApp!.KforScale, colorText: XColors.foregroundLight)))]),
                              SizedBox(height: 5),
                              Row(
                                children: [
                                  Expanded(
                                      child: XBtnbase(
                                    margin: EdgeInsets.symmetric(vertical: 5, horizontal: 40),
                                    label: "Sincronizza",
                                    icon_WidthArea: 30,
                                    label_Color: Colors.red,
                                    backGroundColor: Color.fromARGB(255, 58, 58, 58),
                                    icon: Icons.refresh,
                                    label_Style: XStyles.xStyTextForLargeTitle(Colors.red),
                                    width: width_menuItems ?? menuItem_WidthDefault,
                                    height: height_menuItems,
                                    onPressed: functOnSync != null
                                        ? () async {
                                            functOnSync!();
                                            snackBar_Visible = true;
                                            await Timer(Duration(seconds: 1), () {
                                              snackBar_Visible = false;
                                            });
                                          }
                                        : null,
                                  ))
                                ],
                              ),
                              Row(children: [
                                Expanded(
                                    child: Container(
                                        child: XBtnbase(
                                  margin: EdgeInsets.symmetric(vertical: 5, horizontal: 40),
                                  label: "Font Editor",
                                  icon_WidthArea: 30,
                                  label_Color: Colors.purple,
                                  backGroundColor: Color.fromARGB(255, 58, 58, 58),
                                  icon: Icons.settings,
                                  label_Style: XStyles.xStyTextForLargeTitle(Colors.purple),
                                  width: width_menuItems ?? menuItem_WidthDefault,
                                  height: height_menuItems,
                                  onPressed: fontChange,
                                ))),
                              ]),
                              Row(children: [Expanded(child: bottomArea_Widget ?? Container())])
                            ],
                          )
                        : Container(color: Colors.transparent, width: width_menuItems, height: MediaQuery.of(context).size.height / 1.5, child: XStatefulWidgetBase.LoaderIndicator(syncWithServer, color_Waiter: Colors.amber.shade500, label: "...caricamento dei dati...")),
                  )),
                  SizedBox(height: 15)
                ]),
                snackBar_Visible
                    ? XContainerWithLabel(
                        'Aggiornati con successo i dati dal server',
                        color: Colors.black,
                        textStyle: XStyles.xStyTextForSubDescr(Colors.amber),
                      )
                    : Container()
              ],
            )));
  }
}

class XMenuGroup {
  String key;
  int? idx;
  String? label;
  List<XMenuItem> items = List<XMenuItem>.empty(growable: true);
  Color? label_Color;
  Color? color_BTN;
  IconData? icon_BTN;
  Uint8List? image_Icon_BTN;
  bool expanded = true;
  XMenuGroup(
    this.key, {
    this.label,
    this.idx,
    this.label_Color,
    this.color_BTN,
    this.icon_BTN,
    this.image_Icon_BTN,
    expanded,
    required this.items,
  });
  addMenuItem(XMenuItem item) {
    this.items.add(item);
  }
}

class XMenuItem {
  String key;
  int? idx;
  String? label;
  Color? label_Color;
  Color? color_BTN;
  IconData? icon_BTN;
  Uint8List? image_Icon_BTN;
  XMenuGroup? parent;

  Function(XMenuItem)? onPressed;

  ///uso futuro
  bool active = true;

  XMenuItem(
    this.key, {
    this.label,
    this.idx,
    this.label_Color,
    this.color_BTN,
    this.onPressed,
    this.icon_BTN,
    this.image_Icon_BTN,
    this.parent,
  });
}
